@@ -48,7 +48,7 @@ fail(char *format, ...)
 	fprintf(stderr, ": %s", strerror(errno));
 #endif
     }
- 
+
     putc('\n', stderr);
     abort();
     exit(1);
@@ -72,19 +72,6 @@ getcomponent(char *path, char *name)
     return path;
 }
 
-#ifdef UNIXWARE
-/* The static buffer in Unixware's readdir is too small. */
-struct dirent * readdir(DIR *d)
-{
-    static struct dirent *buf = NULL;
-#define MAX_PATH_LEN 1024
-
-    if (buf == NULL)
-	buf = (struct dirent *)xmalloc(sizeof(struct dirent) + MAX_PATH_LEN) ;
-    return readdir_r(d, buf);
-}
-#endif
-
 /* APPARENT BUG - ignores argument "dir", uses ".." instead. */
 char *
 ino2name(ino_t ino, char *dir)
@@ -123,7 +110,7 @@ xmalloc(size_t size)
 char *
 xstrdup(char *s)
 {
-    if (!s || !s[0]) 
+    if (!s || !s[0])
 	fail("Null pointer or empty string passed to xstrdup()");
     return strcpy((char*)xmalloc(strlen(s) + 1), s);
 }
@@ -133,7 +120,7 @@ xbasename(char *path)
 {
     char *cp;
 
-    if (!path || !path[0]) 
+    if (!path || !path[0])
 	fail("Null pointer or empty string passed to xbasename()");
     while ((cp = strrchr(path, '/')) && cp[1] == '\0')
 	*cp = '\0';
@@ -144,7 +131,7 @@ xbasename(char *path)
 void
 xchdir(char *dir)
 {
-    if (!dir || !dir[0]) 
+    if (!dir || !dir[0])
 	fail("Null pointer or empty string passed to xchdir()");
     if (chdir(dir) < 0)
 	fail("cannot change directory to %s", dir);
@@ -181,7 +168,7 @@ relatepaths(char *from, char *to, char *outpath)
 	    len += 3;
 	}
 	while ((cp = getcomponent(cp, buf)) != 0) {
-	    sprintf(outpath + len, "%s/", buf);
+	    snprintf(outpath + len, PATH_MAX - len, "%s/", buf);
 	    len += strlen(outpath + len);
 	}
     }
@@ -212,7 +199,7 @@ reversepath(char *inpath, char *name, int len, char *outpath)
 	    xchdir("..");
 	} else {
 	    cp -= 3;
-	    strncpy(cp, "../", 3);
+	    memcpy(cp, "../", 3);
 	    xchdir(buf);
 	}
     }
@@ -228,7 +215,7 @@ diagnosePath(const char * path)
     struct stat sb;
     char 	buf[BUFSIZ];
 
-    if (!path || !path[0]) 
+    if (!path || !path[0])
 	fail("Null pointer or empty string passed to mkdirs()");
     myPath = strdup(path);
     if (!myPath)
