@@ -264,6 +264,29 @@ failure:
     return CKR_MECHANISM_PARAM_INVALID;
 }
 
+static PRBool
+kbkdf_ValidPRF(CK_SP800_108_PRF_TYPE prf)
+{
+    // See Table 161 of PKCS#11 v3.0 or Table 192 of PKCS#11 v3.1.
+    switch (prf) {
+        case CKM_AES_CMAC:
+            /* case CKM_DES3_CMAC: */
+            return PR_TRUE;
+        case CKM_SHA_1_HMAC:
+        case CKM_SHA224_HMAC:
+        case CKM_SHA256_HMAC:
+        case CKM_SHA384_HMAC:
+        case CKM_SHA512_HMAC:
+        case CKM_SHA3_224_HMAC:
+        case CKM_SHA3_256_HMAC:
+        case CKM_SHA3_384_HMAC:
+        case CKM_SHA3_512_HMAC:
+            /* Valid HMAC <-> HASH isn't NULL */
+            return sftk_HMACMechanismToHash(prf) != HASH_AlgNULL;
+    }
+    return PR_FALSE;
+}
+
 static CK_RV
 kbkdf_ValidateParameters(CK_MECHANISM_TYPE mech, const CK_SP800_108_KDF_PARAMS *params, CK_ULONG keySize)
 {
@@ -273,14 +296,7 @@ kbkdf_ValidateParameters(CK_MECHANISM_TYPE mech, const CK_SP800_108_KDF_PARAMS *
 
     /* Start with checking the prfType as a mechanism against a list of
      * PRFs allowed by PKCS#11 v3.0. */
-    if (!(/* The following types aren't defined in NSS yet. */
-          /* params->prfType != CKM_3DES_CMAC && */
-          params->prfType == CKM_AES_CMAC || /* allow */
-          /* We allow any HMAC except MD2 and MD5. */
-          params->prfType != CKM_MD2_HMAC ||                        /* disallow */
-          params->prfType != CKM_MD5_HMAC ||                        /* disallow */
-          sftk_HMACMechanismToHash(params->prfType) != HASH_AlgNULL /* Valid HMAC <-> HASH isn't NULL */
-          )) {
+    if (!kbkdf_ValidPRF(params->prfType)) {
         return CKR_MECHANISM_PARAM_INVALID;
     }
 
@@ -819,7 +835,7 @@ kbkdf_CounterRaw(const CK_SP800_108_KDF_PARAMS *params, sftk_MACCtx *ctx, unsign
         }
 
         /* Finalize this iteration of the PRF. */
-        ret = sftk_MAC_Finish(ctx, ret_buffer + buffer_offset, NULL, block_size);
+        ret = sftk_MAC_End(ctx, ret_buffer + buffer_offset, NULL, block_size);
         if (ret != CKR_OK) {
             return ret;
         }
@@ -936,7 +952,7 @@ kbkdf_FeedbackRaw(const CK_SP800_108_KDF_PARAMS *params, const unsigned char *in
          * first save this to the chaining value so that we can reuse it
          * in the next iteration before copying the necessary length to
          * the output buffer. */
-        ret = sftk_MAC_Finish(ctx, chaining_value, NULL, chaining_length);
+        ret = sftk_MAC_End(ctx, chaining_value, NULL, chaining_length);
         if (ret != CKR_OK) {
             goto finish;
         }
@@ -1065,7 +1081,7 @@ kbkdf_PipelineRaw(const CK_SP800_108_KDF_PARAMS *params, sftk_MACCtx *ctx, unsig
 
         /* Save the PRF output to chaining_value for use in the second
          * pipeline. */
-        ret = sftk_MAC_Finish(ctx, chaining_value, NULL, chaining_length);
+        ret = sftk_MAC_End(ctx, chaining_value, NULL, chaining_length);
         if (ret != CKR_OK) {
             goto finish;
         }
@@ -1089,7 +1105,7 @@ kbkdf_PipelineRaw(const CK_SP800_108_KDF_PARAMS *params, sftk_MACCtx *ctx, unsig
         /* Finalize this iteration of the PRF directly to the output buffer.
          * Unlike Feedback mode, this pipeline doesn't influence the previous
          * stage. */
-        ret = sftk_MAC_Finish(ctx, ret_buffer + buffer_offset, NULL, block_size);
+        ret = sftk_MAC_End(ctx, ret_buffer + buffer_offset, NULL, block_size);
         if (ret != CKR_OK) {
             goto finish;
         }
@@ -1128,7 +1144,7 @@ kbkdf_RawDispatch(CK_MECHANISM_TYPE mech,
     CK_RV ret;
     /* Context for our underlying PRF function.
      *
-     * Zeroing context required unconditional call of sftk_MAC_Destroy.
+     * Zeroing context required unconditional call of sftk_MAC_DestroyContext.
      */
     sftk_MACCtx ctx = { 0 };
 
@@ -1227,7 +1243,7 @@ finish:
     PORT_ZFree(output_buffer, buffer_length);
 
     /* Free the PRF. This should handle clearing all sensitive information. */
-    sftk_MAC_Destroy(&ctx, PR_FALSE);
+    sftk_MAC_DestroyContext(&ctx, PR_FALSE);
     return ret;
 }
 
