@@ -14,7 +14,6 @@
 #include "sslimpl.h"
 #include "sslproto.h"
 
-static int ssl_isInited = 0;
 static PRCallOnceType ssl_init = { 0 };
 PR_STATIC_ASSERT(sizeof(unsigned long) <= sizeof(PRUint64));
 
@@ -57,18 +56,11 @@ ssl_InitCallOnce(void *arg)
 SECStatus
 ssl_Init(void)
 {
-    PRStatus nrv;
-
-    /* short circuit test if we are already inited */
-    if (!ssl_isInited) {
-        int error;
-        /* only do this once at init time, block all others until we are done */
-        nrv = PR_CallOnceWithArg(&ssl_init, ssl_InitCallOnce, &error);
-        if (nrv != PR_SUCCESS) {
-            PORT_SetError(error);
-            return SECFailure;
-        }
-        ssl_isInited = 1;
+    int error;
+    PRStatus nrv = PR_CallOnceWithArg(&ssl_init, ssl_InitCallOnce, &error);
+    if (nrv != PR_SUCCESS) {
+        PORT_SetError(error);
+        return SECFailure;
     }
     return SECSuccess;
 }
