@@ -13,20 +13,20 @@
 # The sed line always clears out Windows line endings, replaces tabs with
 # spaces, and removed comments.
 #
+set -e
+
 TESTDIR=${1-.}
 request=${2}
 extraneous_response=${3}
 extraneous_fax=${4}
 name=`basename $request .req`
 echo ">>>>>  $name"
-sed -e 's;
-;;g' -e 's;	; ;g' -e '/^#/d' $extraneous_response ${TESTDIR}/resp/${name}.rsp > /tmp/y1
+sed -e 's;\r;;g' -e 's;	; ;g' -e '/^#/d' $extraneous_response ${TESTDIR}/resp/${name}.rsp > /tmp/y1
 # if we didn't generate any output, flag that as an error
-size=`sum /tmp/y1 | awk '{ print $NF }'`
+size=`sum /tmp/y1 | awk '{ print $1 }'`
 if [ $size -eq 0 ]; then
    echo "${TESTDIR}/resp/${name}.rsp: empty"
    exit 1;
 fi
-sed -e 's;
-;;g' -e 's;	; ;g' -e '/^#/d' $extraneous_fax ${TESTDIR}/fax/${name}.fax > /tmp/y2
+sed -e 's;\r;;g' -e 's;	; ;g' -e '/^#/d' $extraneous_fax ${TESTDIR}/fax/${name}.fax > /tmp/y2
 diff -i -w -B /tmp/y1 /tmp/y2
